@@ -1,6 +1,6 @@
 package PPIx::EditorTools::FindUnmatchedBrace;
 BEGIN {
-  $PPIx::EditorTools::FindUnmatchedBrace::VERSION = '0.11';
+  $PPIx::EditorTools::FindUnmatchedBrace::VERSION = '0.12';
 }
 
 # ABSTRACT: PPI-based unmatched-brace-finder
@@ -17,25 +17,25 @@ use PPI;
 
 
 sub find {
-    my ( $self, %args ) = @_;
-    $self->process_doc(%args);
+	my ( $self, %args ) = @_;
+	$self->process_doc(%args);
 
-    my $ppi = $self->ppi;
+	my $ppi = $self->ppi;
 
-    my $where = $ppi->find( \&PPIx::EditorTools::find_unmatched_brace );
-    if ($where) {
-        @$where = sort {
-            PPIx::EditorTools::element_depth($b)
-              <=> PPIx::EditorTools::element_depth($a)
-              or $a->location->[0] <=> $b->location->[0]
-              or $a->location->[1] <=> $b->location->[1]
-        } @$where;
+	my $where = $ppi->find( \&PPIx::EditorTools::find_unmatched_brace );
+	if ($where) {
+		@$where = sort {
+			       PPIx::EditorTools::element_depth($b) <=> PPIx::EditorTools::element_depth($a)
+				or $a->location->[0] <=> $b->location->[0]
+				or $a->location->[1] <=> $b->location->[1]
+		} @$where;
 
-        return PPIx::EditorTools::ReturnObject->new(
-            ppi     => $ppi,
-            element => $where->[0] );
-    }
-    return;
+		return PPIx::EditorTools::ReturnObject->new(
+			ppi     => $ppi,
+			element => $where->[0]
+		);
+	}
+	return;
 }
 
 1;
@@ -50,7 +50,7 @@ PPIx::EditorTools::FindUnmatchedBrace - PPI-based unmatched-brace-finder
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -108,7 +108,7 @@ Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by The Padre development team as listed in Padre.pm.
+This software is copyright (c) 2011 by The Padre development team as listed in Padre.pm.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
