@@ -1,18 +1,21 @@
 package PPIx::EditorTools::Outline;
+BEGIN {
+  $PPIx::EditorTools::Outline::VERSION = '0.12';
+}
 
-# ABSTRACT: Collect use pragmata, modules, subroutiones, methods, attributes
+# ABSTRACT: PPI-based outline builder
 
 use 5.008;
 use strict;
 use warnings;
 use Carp;
-use Try::Tiny;
+
 use base 'PPIx::EditorTools';
 use Class::XSAccessor accessors => {};
 
 use PPI;
 
-our $VERSION = '0.15_04';
+
 
 sub find {
 	my ( $self, %args ) = @_;
@@ -25,8 +28,6 @@ sub find {
 
 	# Search for interesting things
 	require PPI::Find;
-
-	# TODO things not very discriptive
 	my @things = PPI::Find->new(
 		sub {
 
@@ -68,9 +69,7 @@ sub find {
 						if grep { $thing->module eq $_ } (
 						'Method::Signatures',
 						'MooseX::Declare',
-						'MooseX::Method::Signatures',
-						'Moose::Role',
-						'Moose',
+						'MooseX::Method::Signatures'
 						);
 				}
 			}
@@ -81,24 +80,11 @@ sub find {
 			# last resort, let's analyse further down...
 			my $node1 = $thing->first_element;
 			my $node2 = $thing->child(2);
-
 			next unless defined $node2;
 
-			# Tests for has followed by new line
-			try {
-				no warnings 'exiting'; # suppress warning Exiting eval via next
-				if ( defined $node2->{content} ) {
-					if ( $node2->{content} =~ /\n/ ) {
-						next;
-					}
-				}
-			};
-
 			# Moose attribute declaration
 			if ( $node1->isa('PPI::Token::Word') && $node1->content eq 'has' ) {
-
-				# p $_[1]->next_sibling->isa('PPI::Token::Whitespace');
-				$self->_Moo_Attributes( $node2, $cur_pkg, $thing );
+				push @{ $cur_pkg->{attributes} }, { name => $node2->content, line => $thing->location->[0] };
 				next;
 			}
 
@@ -114,24 +100,14 @@ sub find {
 		$ppi->find(
 			sub {
 				$_[1]->isa('PPI::Token::Word') or return 0;
-				$_[1]->content =~ /^(?:func|method|before|after|around|override|augment|class|role)\z/ or return 0;
+				$_[1]->content =~ /^(?:func|method)\z/ or return 0;
 				$_[1]->next_sibling->isa('PPI::Token::Whitespace') or return 0;
 				my $sib_content = $_[1]->next_sibling->next_sibling->content or return 0;
 
-				my $name = eval $sib_content;
+				$sib_content =~ m/^\b(\w+)\b/;
+				return 0 unless defined $1;
 
-				# if eval() failed for whatever reason, default to original trimmed original token
-				$name ||= ( $sib_content =~ m/^\b(\w+)\b/ )[0];
-
-				return 0 unless defined $name;
-
-				# test for MooseX::Declare class, role
-				if ( $_[1]->content =~ m/(class|role)/ ) {
-					$self->_Moo_PkgName( $cur_pkg, $sib_content, $_[1] );
-					return 1; # break out so we don't write Package name as method
-				}
-
-				push @{ $cur_pkg->{methods} }, { name => $name, line => $_[1]->line_number };
+				push @{ $cur_pkg->{methods} }, { name => $1, line => $_[1]->line_number };
 
 				return 1;
 			}
@@ -147,63 +123,20 @@ sub find {
 	return \@outline;
 }
 
-########
-# Composed Method, internal, Moose Attributes
-# cleans moose attributes up, and single lines them.
-# only runs if PPI finds has
-# prefix all vars with ma_ otherwise same name
-########
-sub _Moo_Attributes {
-	my ( $self, $ma_node2, $ma_cur_pkg, $ma_thing ) = @_;
-
-	my $line_num = $ma_thing->location->[0];
-
-	if ( $ma_node2->content =~ /[\n|;]/ ) {
-		return;
-	}
-
-	my $attrs = eval $ma_node2->content;
-
-	# if eval() failed for whatever reason, default to original token
-	$attrs ||= $ma_node2->content;
-
-	if ( ref $attrs eq 'ARRAY' ) {
-		map { push @{ $ma_cur_pkg->{attributes} }, { name => $_, line => $line_num, } }
-			grep {defined} @{$attrs};
-
-	} else {
-
-		push @{ $ma_cur_pkg->{attributes} },
-			{
-			name => $attrs,
-			line => $line_num,
-			};
-	}
-	return;
-}
-
-########
-# Composed Method, internal, Moose Pakage Name
-# write first Class or Role as Package Name if none
-# prefix all vars with mpn_ otherwise same name
-########
-sub _Moo_PkgName {
-	my ( $self, $mpn_cur_pkg, $mpn_sib_content, $mpn_ppi_tuple ) = @_;
-	if ( $mpn_cur_pkg->{name} ) { return 1; } # break if we have a pkg name
-	                                          # add to outline
-	$mpn_cur_pkg->{name} = $mpn_sib_content;            # class or role name
-	$mpn_cur_pkg->{line} = $mpn_ppi_tuple->line_number; # class or role location
-	return 1;
-}
-
 1;
 
-__END__
-
 
 
 =pod
 
+=head1 NAME
+
+PPIx::EditorTools::Outline - PPI-based outline builder
+
+=head1 VERSION
+
+version 0.12
+
 =head1 SYNOPSIS
 
   my $outline = PPIx::EditorTools::Outline->new->find(
@@ -213,22 +146,18 @@ __END__
 
 =head1 DESCRIPTION
 
-Return a list of pragmatas, modules, methods, attributes of a C<PPI::Document>.
+Return a list of pragmatas, modules, methods of a C<PPI::Document>.
 
 =head1 METHODS
 
 =over 4
 
-=item * new()
+=item new()
 
 Constructor. Generally shouldn't be called with any arguments.
 
-
-=item * find()
-
-	find( ppi => PPI::Document $ppi )
-or
-	find( code => Str $code )
+=item find( ppi => PPI::Document $ppi )
+=item find( code => Str $code )
 
 Accepts either a C<PPI::Document> to process or a string containing
 the code (which will be converted into a C<PPI::Document>) to process.
@@ -236,34 +165,44 @@ Return a reference to a hash.
 
 =back
 
-=head2 Internal Methods
-
-=over 4
-
-=item * _Moo_Attributes
-
-=item * _Moo_PkgName
-
-=back
-
-=head1 AUTHORS
-
-Gabor Szabo E<lt>gabor@szabgab.comE<gt>
-
-=head2 CONTRIBUTORS
-
-Kevin Dawson E<lt>bowtie@cpan.orgE<gt>
-
-buff3r E<lt>buff3r@E<gt>
-
 =head1 SEE ALSO
 
 This class inherits from C<PPIx::EditorTools>.
 Also see L<App::EditorTools>, L<Padre>, and L<PPI>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Steffen Mueller C<smueller@cpan.org>
+
+=item *
+
+Repackaged by Mark Grimes C<mgrimes@cpan.org>
+
+=item *
+
+Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by The Padre development team as listed in Padre.pm.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-# Copyright 2008-2012 The Padre development team as listed in Padre.pm.
+
+__END__
+
+
+# Copyright 2008-2011 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl 5 itself.
+
